*******
Configs
*******
- survey of configs

  - CliConfig

    - DocoptConfig
    - ArgParseConfig

  - FileConfig

    - YamlConfig
    - TomlConfig
    - NtConfig
    - JsonConfig

    - Arguments:

      - Schema
      - Root

  - AppDirsConfig
  - EnvironmentConfig

- setup vs subclass
- init/load, autoload
- on_load
- config_attr
